@@ -1,31 +1,22 @@
-/* This file is part of the KDE libraries
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2007 David Faure <faure@kde.org>
 
-    Copyright (c) 2007 David Faure <faure@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include <QtTest/QtTest>
+#include <QSignalSpy>
+#include <QTest>
 #include <khistorycombobox.h>
 #include <klineedit.h>
 
 class KTestComboBox : public KComboBox
 {
 public:
-    KTestComboBox(bool rw, QWidget *parent = nullptr) : KComboBox(rw, parent) {}
+    KTestComboBox(bool rw, QWidget *parent = nullptr)
+        : KComboBox(rw, parent)
+    {
+    }
     KCompletionBase *delegate() const
     {
         return KCompletionBase::delegate();
@@ -44,25 +35,43 @@ private:
         w.setCompletionMode(KCompletion::CompletionPopup);
         w.addItem(QStringLiteral("Hello world"));
         QVERIFY(w.lineEdit());
-        QVERIFY(qobject_cast<KLineEdit *>(w.lineEdit()));
-        auto lineEdit = w.lineEdit();
+        auto lineEdit = qobject_cast<KLineEdit *>(w.lineEdit());
+        QVERIFY(lineEdit);
+
         // set editable again, don't recreate the line edit
         w.setEditable(true);
         QCOMPARE(w.lineEdit(), lineEdit);
         // KLineEdit signals
         QSignalSpy qReturnPressedSpy(w.lineEdit(), SIGNAL(returnPressed()));
-        QSignalSpy kReturnPressedSpy(w.lineEdit(), SIGNAL(returnPressed(QString)));
+
+#if KCOMPLETION_BUILD_DEPRECATED_SINCE(5, 81)
+        QSignalSpy kEditReturnPressedSpy(lineEdit, QOverload<const QString &>::of(&KLineEdit::returnPressed));
+#endif
+        QSignalSpy kEditReturnKeyPressedSpy(lineEdit, &KLineEdit::returnKeyPressed);
+
         // KComboBox signals
+#if KCOMPLETION_BUILD_DEPRECATED_SINCE(5, 81)
         QSignalSpy comboReturnPressedSpy(&w, SIGNAL(returnPressed()));
-        QSignalSpy comboReturnPressedStringSpy(&w, SIGNAL(returnPressed(QString)));
-        QSignalSpy comboActivatedSpy(&w, SIGNAL(activated(QString)));
+#endif
+        QSignalSpy comboReturnPressedStringSpy(&w, QOverload<const QString &>::of(&KComboBox::returnPressed));
+
+        QSignalSpy comboActivatedSpy(&w, &QComboBox::textActivated);
         QTest::keyClick(&w, Qt::Key_Return);
         QCOMPARE(qReturnPressedSpy.count(), 1);
-        QCOMPARE(kReturnPressedSpy.count(), 1);
-        QCOMPARE(kReturnPressedSpy[0][0].toString(), QString("Hello world"));
+
+#if KCOMPLETION_BUILD_DEPRECATED_SINCE(5, 81)
+        QCOMPARE(kEditReturnPressedSpy.count(), 1);
+        QCOMPARE(kEditReturnPressedSpy[0][0].toString(), QString("Hello world"));
+#endif
+        QCOMPARE(kEditReturnKeyPressedSpy.count(), 1);
+        QCOMPARE(kEditReturnKeyPressedSpy.at(0).at(0).toString(), QStringLiteral("Hello world"));
+
+#if KCOMPLETION_BUILD_DEPRECATED_SINCE(5, 81)
         QCOMPARE(comboReturnPressedSpy.count(), 1);
+#endif
         QCOMPARE(comboReturnPressedStringSpy.count(), 1);
         QCOMPARE(comboReturnPressedStringSpy[0][0].toString(), QString("Hello world"));
+
         QCOMPARE(comboActivatedSpy.count(), 1);
         QCOMPARE(comboActivatedSpy[0][0].toString(), QString("Hello world"));
     }
@@ -78,17 +87,21 @@ private Q_SLOTS:
     {
         KHistoryComboBox w;
         QVERIFY(qobject_cast<KLineEdit *>(w.lineEdit()));
-        connect(&w, SIGNAL(activated(QString)),
-                &w, SLOT(addToHistory(QString)));
+#if KCOMPLETION_BUILD_DEPRECATED_SINCE(5, 81)
         QSignalSpy comboReturnPressedSpy(&w, SIGNAL(returnPressed()));
+#endif
         QSignalSpy comboReturnPressedStringSpy(&w, SIGNAL(returnPressed(QString)));
-        QSignalSpy comboActivatedSpy(&w, SIGNAL(activated(QString)));
+        connect(&w, &KHistoryComboBox::textActivated, &w, &KHistoryComboBox::addToHistory);
+        QSignalSpy comboActivatedSpy(&w, &QComboBox::textActivated);
         QTest::keyClicks(&w, QStringLiteral("Hello world"));
         QTest::keyClick(&w, Qt::Key_Return);
         qApp->processEvents(); // QueuedConnection in KHistoryComboBox
+#if KCOMPLETION_BUILD_DEPRECATED_SINCE(5, 81)
         QCOMPARE(comboReturnPressedSpy.count(), 1);
+#endif
         QCOMPARE(comboReturnPressedStringSpy.count(), 1);
         QCOMPARE(comboReturnPressedStringSpy[0][0].toString(), QString("Hello world"));
+
         QCOMPARE(comboActivatedSpy.count(), 1);
         QCOMPARE(comboActivatedSpy[0][0].toString(), QString("Hello world"));
     }
@@ -117,8 +130,8 @@ private Q_SLOTS:
 
     void testHistoryComboReset()
     {
-        //It only tests that it doesn't crash
-        //TODO: Finish
+        // It only tests that it doesn't crash
+        // TODO: Finish
         KHistoryComboBox combo;
         QStringList items;
         items << QStringLiteral("One") << QStringLiteral("Two");
@@ -129,7 +142,7 @@ private Q_SLOTS:
     void testDeleteLineEdit()
     {
         // Test for KCombo's KLineEdit destruction
-        KTestComboBox *testCombo = new KTestComboBox(true, nullptr);   // rw, with KLineEdit
+        KTestComboBox *testCombo = new KTestComboBox(true, nullptr); // rw, with KLineEdit
         testCombo->setEditable(false); // destroys our KLineEdit, with deleteLater
         qApp->sendPostedEvents(nullptr, QEvent::DeferredDelete);
         QVERIFY(testCombo->KTestComboBox::delegate() == nullptr);
@@ -162,7 +175,7 @@ private Q_SLOTS:
             QVERIFY(completion); // completion is still alive
 
             // verify that the completion object was set on the line edit
-            lineEdit = qobject_cast<KLineEdit*>(testCombo.lineEdit());
+            lineEdit = qobject_cast<KLineEdit *>(testCombo.lineEdit());
             QVERIFY(lineEdit);
             QVERIFY(lineEdit->compObj());
             QCOMPARE(lineEdit->compObj(), completion.data());
@@ -179,7 +192,7 @@ private Q_SLOTS:
                 // but we get a new one from the second line edit
                 completion = testCombo.completionObject();
             }
-                QVERIFY(completion);
+            QVERIFY(completion);
             QCOMPARE(lineEdit2->compObj(), completion.data());
             QCOMPARE(testCombo.completionObject(), completion.data());
         }
